import Alpine from 'alpinejs';
import focus from '@alpinejs/focus';
import collapse from '@alpinejs/collapse';
import intersect from '@alpinejs/intersect';
import * as d3 from 'd3';

Alpine.plugin(focus);
Alpine.plugin(collapse);
Alpine.plugin(intersect);

const stateNames = {
  AL: "Alabama", AK: "Alaska", AZ: "Arizona", AR: "Arkansas", CA: "California",
  CO: "Colorado", CT: "Connecticut", DE: "Delaware", FL: "Florida", GA: "Georgia",
  HI: "Hawaii", ID: "Idaho", IL: "Illinois", IN: "Indiana", IA: "Iowa",
  KS: "Kansas", KY: "Kentucky", LA: "Louisiana", ME: "Maine", MD: "Maryland",
  MA: "Massachusetts", MI: "Michigan", MN: "Minnesota", MS: "Mississippi", MO: "Missouri",
  MT: "Montana", NE: "Nebraska", NV: "Nevada", NH: "New Hampshire", NJ: "New Jersey",
  NM: "New Mexico", NY: "New York", NC: "North Carolina", ND: "North Dakota", OH: "Ohio",
  OK: "Oklahoma", OR: "Oregon", PA: "Pennsylvania", RI: "Rhode Island", SC: "South Carolina",
  SD: "South Dakota", TN: "Tennessee", TX: "Texas", UT: "Utah", VT: "Vermont",
  VA: "Virginia", WA: "Washington", WV: "West Virginia", WI: "Wisconsin", WY: "Wyoming"
};
document.addEventListener('DOMContentLoaded', function () {
  const bioContainer = document.getElementById('full-width-bio');
  const bioContent = document.getElementById('bio-content');
  const closeBioButton = document.getElementById('close-bio');
  document.querySelectorAll('.bio-toggle').forEach(button => {
    button.addEventListener('click', () => {
      const bioHtml = button.getAttribute('data-bio-content');
      bioContent.innerHTML = bioHtml;
      bioContainer.classList.remove('hidden', 'max-h-0', 'opacity-0');
    });
  });
  window.toggleMenu = function () {
    const mobileNav = document.getElementById('mobileNav');
    const hamburgerMenu = document.getElementById('hamburgerMenu');
    mobileNav.classList.toggle('hidden');
    hamburgerMenu.classList.toggle('is-active');
  
    // Ensure subnav visibility matches screen size
    if (window.innerWidth >= 768) {
      document.querySelectorAll('.mobile-subnav').forEach(el => el.classList.add('hidden'));
      document.querySelectorAll('.desktop-nav').forEach(el => el.classList.remove('hidden'));
    } else {
      document.querySelectorAll('.mobile-subnav').forEach(el => el.classList.remove('hidden'));
      document.querySelectorAll('.desktop-nav').forEach(el => el.classList.add('hidden'));
    }
  }
  window.toggleMobileSubMenu = function (parentId) {
    const submenu = document.getElementById('submenu-' + parentId);
    if (submenu) {
      submenu.classList.toggle('hidden');
    }
  }
  window.showSubMenu = function (parentId) {
    const subNavLinks = document.querySelectorAll('#subnav .flex a');
    subNavLinks.forEach(el => el.classList.add('hidden'));
    const matchingSubNavLinks = document.querySelectorAll(`#subnav .flex a[data-parent-id="${parentId}"]`);
    matchingSubNavLinks.forEach(el => el.classList.remove('hidden'));
  }
  const topLevelLinks = document.querySelectorAll('.md-custom\\:inline-block a[data-nav-id]');
  topLevelLinks.forEach(el => {
    el.addEventListener('mouseover', function () {
      showSubMenu(this.dataset.navId);
    });
    el.addEventListener('click', function () {
      // Immediately hide other links when clicking on a new top-level link
      document.querySelectorAll('.subnav').forEach(subEl => subEl.classList.add('hidden'));
      showSubMenu(this.dataset.navId); // Show only relevant subnav items
    });
  });
  const navArea = document.querySelector('.md-custom\\:inline-block');
  navArea.addEventListener('mouseleave', function () {
    document.querySelectorAll('#subnav .flex a').forEach(subEl => subEl.classList.add('hidden'));
  });
});
function traceabilityMap() {
  const coords = {
    "AL": { "top": "60%", "left": "76%" },
    "AK": { "top": "10%", "left": "-5%" },  // Might need to adjust because negative left values might not be visible
    "AZ": { "top": "52%", "left": "15%" },
    "AR": { "top": "62%", "left": "61%" },
    "CA": { "top": "42%", "left": "0%" },   // Check for visibility if too far left
    "CO": { "top": "47%", "left": "25%" },
    "CT": { "top": "76%", "left": "88%" },
    "DE": { "top": "77%", "left": "84%" },
    "DC": { "top": "78%", "left": "83%" },
    "FL": { "top": "87%", "left": "78%" },
    "GA": { "top": "74%", "left": "75%" },
    "HI": { "top": "91%", "left": "-2%" },
    "ID": { "top": "40%", "left": "12%" },
    "IL": { "top": "57%", "left": "65%" },
    "IN": { "top": "60%", "left": "70%" },
    "IA": { "top": "52%", "left": "60%" },
    "KS": { "top": "57%", "left": "45%" },
    "KY": { "top": "67%", "left": "75%" },
    "LA": { "top": "72%", "left": "60%" },
    "ME": { "top": "66%", "left": "89%" },
    "MD": { "top": "76%", "left": "82%" },
    "MA": { "top": "70%", "left": "86%" },
    "MI": { "top": "54%", "left": "73%" },
    "MN": { "top": "42%", "left": "55%" },
    "MS": { "top": "77%", "left": "65%" },
    "MO": { "top": "62%", "left": "55%" },
    "MT": { "top": "32%", "left": "30%" },
    "NE": { "top": "50%", "left": "45%" },
    "NV": { "top": "37%", "left": "10%" },
    "NH": { "top": "69%", "left": "86%" },
    "NJ": { "top": "76%", "left": "84%" },
    "NM": { "top": "57%", "left": "25%" },
    "NY": { "top": "70%", "left": "80%" },
    "NC": { "top": "72%", "left": "75%" },
    "ND": { "top": "14%", "left": "45%" },
    "OH": { "top": "64%", "left": "75%" },
    "OK": { "top": "67%", "left": "50%" },
    "OR": { "top": "27%", "left": "5%" },
    "PA": { "top": "72%", "left": "80%" },
    "RI": { "top": "72%", "left": "87%" },
    "SC": { "top": "77%", "left": "75%" },
    "SD": { "top": "30%", "left": "45%" },
    "TN": { "top": "72%", "left": "70%" },
    "TX": { "top": "72%", "left": "45%" },
    "UT": { "top": "47%", "left": "20%" },
    "VT": { "top": "67%", "left": "85%" },
    "VA": { "top": "74%", "left": "78%" },
    "WA": { "top": "22%", "left": "5%" },
    "WV": { "top": "70%", "left": "75%" },
    "WI": { "top": "52%", "left": "67%" },
    "WY": { "top": "42%", "left": "35%" },
  };
  return {
    lotCode: '',
    locations: [],
    init() {
      this.locations = [];
    },
    fetchLotCodes() {
      fetch(`/api/lots?lot_number=${this.lotCode}`)
        .then(response => {
          if (!response.ok) {
            throw new Error('Network response was not ok');
          }
          return response.json();
        })
        .then(data => {
          this.locations = data.data
            .filter(entry => entry.state_code && coords[entry.state_code])
            .map((entry, index) => ({
              name: stateNames[entry.state_code],
              coordinates: this.getStateCoords(entry.state_code),
              id: entry.id || index
            }));
          console.log('Filtered and processed locations:', this.locations);
          this.plotLocations();
        })
        .catch(error => {
          console.error('Error:', error);
          this.locations = [];
        });
    },
    getStateCoords(stateCode) {
      return coords[stateCode] || null;
    },
    plotLocations() {
      const mapElement = document.getElementById('map-markers');
      if (!mapElement) return;
      mapElement.innerHTML = '';
      this.locations.forEach(location => {
        if (location.coordinates) {
          const marker = document.createElement('div');
          marker.style = `position: absolute; top: ${location.coordinates.top}; left: ${location.coordinates.left}; transform: translate(-50%, -50%); display: flex; flex-direction: column; align-items: center;`;
          marker.innerHTML = `<img src="/assets/product-tracability-instr-trifoil.png" class="marker-icon" alt="Marker Icon"><div>${location.name}</div>`;
          mapElement.appendChild(marker);
        }
      });
    }
  };
}
function slider() {
  const allMonths = ['Jan', 'Feb', 'Mar', 'Apr', 'May', 'Jun', 'Jul', 'Aug', 'Sep', 'Oct', 'Nov', 'Dec'];
  const historicalFacts = {
    'Jan': 'Little work is required at the hives. If there is snow, make sure the entrance to the hive is cleared to allow proper ventilation. If a January thaw occurs you will need to provide supplemental emergency food for the bees.',
    'Feb': 'Read, learn, attend classes/workshops.',
    'Mar': 'On a mild day, early in the month, with no wind or bees flying, peek inside your hive. If you don’t see any sealed honey in the top frames, you may need to provide emergency food. Once you start feeding them, do not stop until they are bringing in their own food. This is also the time to treat for Varroa mites, if needed.  Although not a harm to the stored honey, Varroa mites resemble reddish dots and latch on to bees draining the bees\' blood-like fluid from their bodies, ultimately killing them.',
    'Apr': 'Do your first comprehensive inspection on a warm, still day. Look for the queen and check to see if there are plenty of eggs and brood. Later in the month you should consider reversing the hive bodies.',
    'May': 'Spring mite treatments should be completed and removed prior to adding any honey supers. Add a queen excluder and place honey supers on top of the top deep. Inspect the hive weekly.',
    'Jun': 'Inspect the hive weekly to make sure the hive is healthy and the queen is present. Add honey supers as needed.',
    'Jul': 'Continue inspections to assure the health of your colony. Add more honey supers if needed.',
    'Aug': 'Watch for honey robbing by wasps or other bees.',
    'Sep': 'Harvest your honey crop. Remember to leave the colony with at least 60 pounds of honey for winter. Check for the queen’s presence. Feed and medicate toward the end of the month. Apply mite treatment. Continue feeding until the bees will take no more.',
    'Oct': 'Watch out for robbing. Prepare the hive for winter, with attention to ventilation and moisture control. Install a mouse guard at entrance of hive. Finish winter feeding.',
    'Nov': 'Store your equipment away for the winter.',
    'Dec': 'This is a good time to continue expanding your knowledge on beekeeping through education.'
  };
  return {
    currentMonthIndex: allMonths.indexOf(new Date().toLocaleString('default', { month: 'short' })),
    visibleMonths: [],
    historicalFact: '',
    init() {
      this.updateVisibleMonths();
      this.updateHistoricalFact();
    },
    updateVisibleMonths() {
      this.visibleMonths = [
        allMonths[(this.currentMonthIndex + 10) % 12],
        allMonths[(this.currentMonthIndex + 11) % 12],
        allMonths[this.currentMonthIndex],
        allMonths[(this.currentMonthIndex + 1) % 12],
        allMonths[(this.currentMonthIndex + 2) % 12]
      ];
    },
    updateHistoricalFact() {
      const currentMonth = allMonths[this.currentMonthIndex];
      this.historicalFact = historicalFacts[currentMonth];
    },
    selectMonth(index) {
      this.currentMonthIndex = (this.currentMonthIndex + index - 2 + 12) % 12;
      console.log('selected');
      this.updateVisibleMonths();
      this.updateHistoricalFact();
    },
    incrementMonth() {
      this.currentMonthIndex = (this.currentMonthIndex + 1) % 12;
      console.log('incrementing');
      this.updateVisibleMonths();
      this.updateHistoricalFact();
    },
    decrementMonth() {
      this.currentMonthIndex = (this.currentMonthIndex - 1 + 12) % 12;
      console.log('decrementing');
      this.updateVisibleMonths();
      this.updateHistoricalFact();
    },
  };
}
function slider_honey() {
  const allDates = [
    '2400 B.C.', '1622', '1673', '1750', '1840s', '1852', '1865', '1906', '1922', '1949', '1952', '1987', '2006'
  ];
  const dateIndexMapping = {
    '2400 B.C.': -2400,
    '1622': 1622,
    '1673': 1673,
    '1750': 1750,
    '1840s': 1840, // Using the lower bound of the decade for sorting purposes
    '1852': 1852,
    '1865': 1865,
    '1906': 1906,
    '1922': 1922,
    '1949': 1949,
    '1952': 1952,
    '1987': 1987,
    '2006': 2006
  };
  // Sort the dates chronologically based on the mapped value
  allDates.sort((a, b) => dateIndexMapping[a] - dateIndexMapping[b]);
  const historicalFacts = {
    '2400 B.C.': 'First documentation of beekeeping in Cairo.',
    '1622': 'Honeybees were shipped from Europe to North America.',
    '1673': 'Dutch biologist and microscopist Jan Swammerdam’s study of honeybee anatomy and behavior began, providing a strong foundation for future bee studies.',
    '1750': 'Arthur Dobbs published the first explanation of the relationship between bees and flowers and the pollination process.',
    '1840s': 'First commercial beekeeping operation in the United States was founded.',
    '1852': 'L. L. Langstroth, “the father of modern beekeeping,” patented a hive with movable frames that is still used today.',
    '1865': 'Centrifugal honey extractor was invented which revolutionized honey packing by quickly and efficiently removing honey from the hive frames.',
    '1906': 'The Pure Food and Drug Act gave buyers more confidence in the purity of extracted honey, thereby increasing demand.',
    '1922': 'Alarmed at the damage tracheal mites were doing to honey bees in Europe, the United States Congress passed a Honey Bee Restriction Act which halted importation of bees to prevent the spread of tracheal mites. Tracheal mites kill bees by clogging breathing airways which restrict oxygen and ultimately suffocate the bees.',
    '1949': 'Dr. Eva Crane, a widely renown female scientist, bee researcher and author, established the Bee Research Association (BRA), which became an international organization in 1976 (IBRA).',
    '1952': 'The IBRA Bee Boles Register was started by Dr. Eva Crane. A bee bole is a protective cavity along a rock wall in which a skep (a coiled straw hive) is placed for capturing honey out of the wind and rain.',
    '1987': 'Varroa mites arrive, causing U.S. beekeepers to lose 50-80% of their colonies. Varroa mites slowly kill a hive by piercing the bee\'s body and sucking out its bodily fluids.',
    '2006': 'First report of Colony Collapse Disorder, a disorder marked by the sudden disappearance or death of a hive, was recorded.'
  };
  const images = {
    '2400 B.C.': '/assets/vintage-sphinx_pyramids_dreamstime_27474733-cropped.jpg',
    '1622': '/assets/bees-life-3.png',
    '1673': '/assets/bee_drawings_dreamstime_51110323_cropped.jpg',
    '1750': '/assets/1750_bee_with_purple_flower_crop.jpg',
    '1840s': '/assets/1840_BeeBox_color1.jpg',
    '1852': '/assets/1852_beeyard0825_cropped.jpg',
    '1865': '/assets/honey-splitting-machinedreamstime_27121970_cropped.jpg',
    '1906': '/assets/1906_BHPlant201411_474LR.jpg',
    '1922': '/assets/bees_nest_dreamstime_49251643_cropped.jpg',
    '1949': '',  // Update with the correct image name if available
    '1952': '',  // Update with the correct image name if available
    '1987': '',  // Update with the correct image name if available
    '2006': '/assets/bees_nest_dreamstime_49251643_cropped.jpg'
  };
  
  const sources = {
    '2400 B.C.': 'http://www.honeyassociation.com/index.asp?pid=9',
    '1622': '',
    '1673': 'http://www.janswammerdam.org/bees.html',
    '1750': '',
    '1840s': 'http://exhibits.mannlib.cornell.edu/beekeeping/atlantic/page3.html',
    '1852': '',
    '1865': '',
    '1906': 'http://www.beesource.com',
    '1922': 'http://topics.blogs.nytimes.com/2008/04/11/honey-bees-a-history/?_r=0',
    '1949': 'http://www.evacranetrust.org/page/eva-crane',
    '1952': 'http://www.gardenhistorysociety.org/post/agenda/bee-boles/',
    '1987': 'http://topics.blogs.nytimes.com/2008/04/11/honey-bees-a-history/?_r=0',
    '2006': 'http://en.wikipedia.org/wiki/Colony_collapse_disorder'
  };
  
  
  return {
    currentMonthIndex: allDates.indexOf('2400 B.C.'),  // Center on the "2400 B.C."
    visibleMonths: [],
    historicalFact: '',
    image: '',
    source: '',
    init() {
      this.updateVisibleMonths();
      this.updateContent();
    },
    updateVisibleMonths() {
      // Adjust visible months based on currentMonthIndex, ensuring 2006 is to the left
      const len = allDates.length;
      this.visibleMonths = [
        allDates[(this.currentMonthIndex - 2 + len) % len], // Two steps left of the center
        allDates[(this.currentMonthIndex - 1 + len) % len], // One step left of the center
        allDates[this.currentMonthIndex],                   // Center date (2400 B.C.)
        allDates[(this.currentMonthIndex + 1) % len],       // One step right of the center
        allDates[(this.currentMonthIndex + 2) % len]        // Two steps right of the center
      ];
    },
    updateContent() {
      const currentMonth = allDates[this.currentMonthIndex];
      this.historicalFact = historicalFacts[currentMonth];
      this.image = images[currentMonth];
      this.source = sources[currentMonth];
    },
    selectMonth(index) {
      this.currentMonthIndex = (this.currentMonthIndex + index - 2 + allDates.length) % allDates.length;
      this.updateVisibleMonths();
      this.updateContent();
    },
    incrementMonth() {
      this.currentMonthIndex = (this.currentMonthIndex + 1) % allDates.length;
      this.updateVisibleMonths();
      this.updateContent();
    },
    decrementMonth() {
      this.currentMonthIndex = (this.currentMonthIndex - 1 + allDates.length) % allDates.length;
      this.updateVisibleMonths();
      this.updateContent();
    }
  };
}
function stateMap() {
  const stateFlowerMapping = {
    'AL': { Alfalfa: 'not abundant', Apple: 'not abundant' },
    'AK': { Alfalfa: 'not abundant', Apple: 'not abundant' },
    'AZ': { Alfalfa: 'abundant', Apple: 'not abundant' },
    'AR': { Alfalfa: 'not abundant', Apple: 'abundant' },
    'CA': { Alfalfa: 'abundant', Apple: 'abundant' },
  };
  return {
    selectedState: '',
    tooltipVisible: false,
    tooltipX: 0,
    tooltipY: 0,
    tooltipContent: '',
    selectedFlower: '',
    init() {
      this.hideSpecificStates();
      this.setInitialStateColors();
    },
    hideSpecificStates() {
      const svgDoc = document.getElementById('us-svg').contentDocument;
      if (!svgDoc) return;
      const hawaii = svgDoc.getElementById('HI');
      const alaska = svgDoc.getElementById('AK');
      if (hawaii) hawaii.style.display = 'none';
      if (alaska) alaska.style.display = 'none';
      const hawaiiPath = svgDoc.getElementById('path57');
      const alaskaPath = svgDoc.getElementById('path58');
      if (hawaiiPath) hawaiiPath.style.display = 'none';
      if (alaskaPath) alaskaPath.style.display = 'none';
    },
    setInitialStateColors() {
      const svgDoc = document.getElementById('us-svg').contentDocument;
      if (!svgDoc) return;
      svgDoc.querySelectorAll('path').forEach(path => {
        path.style.fill = '#f6be00';
      });
    },
    changeStateColor() {
      const svgDoc = document.getElementById('us-svg').contentDocument;
      if (!svgDoc) return;
      svgDoc.querySelectorAll('path').forEach(path => {
        path.style.fill = '#f6be00';
      });
      if (this.selectedState) {
        const stateElement = svgDoc.getElementById(this.selectedState);
        if (stateElement) {
          stateElement.style.fill = '#e5e1d4';
        }
      }
    },
    showStateTooltip(event) {
      const svgDoc = document.getElementById('us-svg').contentDocument;
      if (event.target.tagName === 'path') {
        this.tooltipContent = event.target.id;
        this.tooltipVisible = true;
        this.tooltipX = event.clientX;
        this.tooltipY = event.clientY;
      }
    },
    hideStateTooltip(event) {
      if (event.target.tagName === 'path') {
        this.tooltipVisible = false;
      }
    },
    filterByFlower() {
      const svgDoc = document.getElementById('us-svg').contentDocument;
      if (!svgDoc) return;
      svgDoc.querySelectorAll('path').forEach(path => {
        path.style.fill = '#f6be00';
      });
      const selectedFlower = this.selectedFlower;
      for (const state in stateFlowerMapping) {
        const flowerStatus = stateFlowerMapping[state][selectedFlower];
        const stateElement = svgDoc.getElementById(state);
        if (stateElement) {
          if (flowerStatus === 'abundant') {
            stateElement.style.fill = '#f6be00';
          } else {
            stateElement.style.fill = 'gray';
          }
        }
      }
    },
  };
}
document.addEventListener('DOMContentLoaded', () => {
  document.querySelectorAll('a').forEach(link => {
    try {
      const href = new URL(link.href, window.location.href); // Use window.location.href as the base URL
      if (href.origin !== window.location.origin) {
        link.target = '_blank';
        link.rel = 'noopener noreferrer'; // This is important for security and performance
      }
    } catch (error) {
      console.error('Error processing link with href:', link.href, error);
    }
  });
});
document.addEventListener('DOMContentLoaded', function () {
  // Custom function to show 'ABOUT' sublinks by default on the homepage.
  function showDefaultSubNavOnHomepage() {
    const body = document.querySelector('body');

    // Check if we're on the homepage using the 'home-page' class.
    if (body && body.classList.contains('home-page')) {
      // Find the ABOUT link in the top-level navigation and trigger its submenu.
      const aboutLink = document.querySelector('.md-custom\\:inline-block a[data-nav-id="about"]');
      if (aboutLink) {
        showSubMenu('about'); // Custom function to reveal sublinks for the 'about' section.
      }
    }
  }

  // Call the function on page load.
  showDefaultSubNavOnHomepage();
});

document.addEventListener("DOMContentLoaded", function () {
  const options = document.querySelectorAll(".contact-input option[disabled]");
  options.forEach(option => {
    option.style.color = '#faefd2';
  });
});
document.addEventListener('DOMContentLoaded', function () {
  // Mapping of subpage URLs to top-level navigation URLs
  const navMap = {
    // About
    '/about/story': '/about',
    '/about/mission-protect-the-honeybees': '/about',
    '/about/promise': '/about',
    '/about/h1ve': '/about',
    '/about/values': '/about',
    // Bees
    '/bees/bees-the-environment': '/bees',
    '/bees/how-bees-make-honey': '/bees',
    '/bees/beekeeping-resources': '/bees',
    // Honey
    '/honey/honey-history': '/honey',
    '/honey/processhow-its-made': '/honey',
    '/honey/nutrition': '/honey',
    '/honey/faq': '/honey',
    // Kitchen
    '/kitchen/recipes': '/kitchen',
    '/kitchen/honey-pairings': '/kitchen',
    '/kitchen/tips-tricks': '/kitchen',
    '/kitchen/storage-shelf-life': '/kitchen',
    // Products
    '/products/branded': '/products',
    '/products/trace-your-honey': '/products',
    '/products/other-sweeteners': '/products',
    '/products/private-label': '/products',
    // Contact
    '/contact/contact-us': '/contact',
    '/contact/our-sweet-honey-buyers': '/contact'
  };
  // Get the current URL path
  let currentPath = window.location.pathname;
  // Remove trailing slash from currentPath if present
  if (currentPath.endsWith('/')) {
    currentPath = currentPath.slice(0, -1);
  }
  console.log('Current path:', currentPath);
  // Function to find the matching top-level URL
  function getTopLevelUrl(path) {
    // Check if current path is a key in navMap
    if (navMap.hasOwnProperty(path)) {
      return navMap[path];
    }
    // If not, check if the path starts with any of the keys
    for (let key in navMap) {
      if (path.startsWith(key)) {
        return navMap[key];
      }
    }
    // If no match, return the root path
    return '/';
  }
  // Get the top-level URL to highlight
  const topLevelUrl = getTopLevelUrl(currentPath);
  console.log('Top level URL:', topLevelUrl);
  // Find the navigation link with href matching topLevelUrl
  const navLinks = document.querySelectorAll('.navver_url');
  console.log('Found navigation links:', navLinks.length);
  navLinks.forEach(link => {
    let linkHref = link.getAttribute('href');
    // Remove trailing slash from linkHref if present
    if (linkHref.endsWith('/')) {
      linkHref = linkHref.slice(0, -1);
    }
    console.log('Checking linkHref:', linkHref);
    // Check if the linkHref matches the topLevelUrl
    if (linkHref === topLevelUrl) {
      console.log('Match found. Adding active-link to:', link);
      link.classList.add('active-link');
    }
  });
});
document.addEventListener('DOMContentLoaded', function () {
  window.showSubMenu = function (parentId) {
    const subNavLinks = document.querySelectorAll('#subnav .flex a');
    subNavLinks.forEach(el => el.classList.add('hidden')); // Hide all submenus
    const matchingSubNavLinks = document.querySelectorAll(`#subnav .flex a[data-parent-id="${parentId}"]`);
    matchingSubNavLinks.forEach(el => el.classList.remove('hidden')); // Show only relevant submenu items
 }
 
 const topLevelLinks = document.querySelectorAll('.md-custom\\:inline-block a[data-nav-id]');
 topLevelLinks.forEach(el => {
    el.addEventListener('mouseenter', function () {
       showSubMenu(this.dataset.navId); // Trigger showSubMenu on hover
    });
 });

 const navArea = document.querySelector('.md-custom\\:inline-block');
 navArea.addEventListener('mouseleave', function () {
    document.querySelectorAll('#subnav .flex a').forEach(subEl => subEl.classList.add('hidden')); // Hide all on mouse leave
 });

    // For homepage
    function showDefaultSubNavOnHomepage() {
      const body = document.querySelector('body');
      if (body && body.classList.contains('home-page')) {
         // Ensures 'About' subnav is not open by default on homepage
         const aboutLink = document.querySelector('.md-custom\\:inline-block a[data-nav-id="about"]');
         if (aboutLink) {
            showSubMenu('about');
         }
      }
   }
   showDefaultSubNavOnHomepage();
});

document.addEventListener('DOMContentLoaded', function () {
  const bioContainer = document.getElementById('full-width-bio');
  const bioContent = document.getElementById('bio-content');
  const closeBioButton = document.getElementById('close-bio');
  
  document.querySelectorAll('.bio-toggle').forEach(button => {
    button.addEventListener('click', () => {
      const bioHtml = button.getAttribute('data-bio-content');
      bioContent.innerHTML = bioHtml;
      bioContainer.classList.remove('hidden', 'max-h-0', 'opacity-0');
    });
  });

  window.toggleMenu = function () {
    document.getElementById('mobileNav').classList.toggle('hidden');
    document.getElementById('hamburgerMenu').classList.toggle('is-active');
  }

  window.toggleMobileSubMenu = function (parentId) {
    const submenu = document.getElementById('submenu-' + parentId);
    if (submenu) {
      submenu.classList.toggle('hidden');
    }
  }

  window.showSubMenu = function (parentId) {
    const subNavLinks = document.querySelectorAll('#subnav .flex a');
    subNavLinks.forEach(el => el.classList.add('hidden'));
    const matchingSubNavLinks = document.querySelectorAll(`#subnav .flex a[data-parent-id="${parentId}"]`);
    matchingSubNavLinks.forEach(el => el.classList.remove('hidden'));
  }

  // Function to show sub-navigation links for the current parent on page load
  function showActiveParentSubNav() {
    // Get the parent nav ID of the current page
    const activeParent = document.querySelector('.md-custom\\:inline-block a.active-link[data-nav-id]');
    if (activeParent) {
      showSubMenu(activeParent.dataset.navId);
    }
  }

  // Initialize sub-navigation visibility on page load
  showActiveParentSubNav();

  const topLevelLinks = document.querySelectorAll('.md-custom\\:inline-block a[data-nav-id]');
  topLevelLinks.forEach(el => {
    el.addEventListener('mouseover', function () {
      showSubMenu(this.dataset.navId);
    });
  });

  const navArea = document.querySelector('.md-custom\\:inline-block');
  navArea.addEventListener('mouseleave', function () {
    document.querySelectorAll('#subnav .flex a').forEach(subEl => subEl.classList.add('hidden'));
  });
});

document.addEventListener('DOMContentLoaded', function () {
  const navTree = [];

  // Recursive function to generate a tree structure for the navigation
  function buildNavTree(element, depth = 1) {
      const children = element.querySelectorAll(`.navver a[data-nav-id]`);
      const subtree = [];

      children.forEach(child => {
          const title = child.textContent.trim();
          const url = child.getAttribute('href');
          const hasChildren = child.closest(`.depth-${depth}`) && child.nextElementSibling;

          const node = {
              title: title,
              url: url,
              children: hasChildren ? buildNavTree(child.closest(`.depth-${depth}`), depth + 1) : []
          };

          console.log(`Node added: ${JSON.stringify(node)}`);  // Debugging log for each node
          subtree.push(node);
      });

      return subtree;
  }

  // Initialize tree generation starting from depth 1
  const navRoot = document.querySelector('.navver');
  if (navRoot) {
      const navStructure = buildNavTree(navRoot, 1);
      console.log('Final Navigation Structure:', JSON.stringify(navStructure, null, 2));
  } else {
      console.error('Navigation root not found');
  }
});




Alpine.data('traceabilityMap', traceabilityMap);
Alpine.data('stateMap', stateMap);
Alpine.data('slider', slider);
Alpine.data('slider_honey', slider_honey);

window.Alpine = Alpine;
Alpine.start();
